@@ -1,4 +1,9 @@
-
+#' shapeR: Otholith analysis
+#'
+#' Collection and analysis of otolith shape data
+#'
+#' @keywords internal
+"_PACKAGE"
 
 #' @import pixmap
 #' @import wavethresh
@@ -15,7 +20,6 @@
 #' @title shapeR
 #' @description Collection and analysis of otolith shape data
 #' @name shapeR
-#' @docType package
 #' @author Lisa Anne Libungan & Snaebjorn Palsson
 NULL
 
@@ -204,8 +208,8 @@ setValidity("shapeR",
 #' @title Get wavelet/Fourier coefficients and basic shape variables
 #' @description Generates shape variables based on Fourier/wavelet reconstruction. Wavelet coefficients for wavelet. Basic shape parameters are also collected (area, length, width, perimeter).
 #' @usage generateShapeCoefficients(object,...)
-#' @param object \code{\linkS4class{shapeR}} object
-#' @param ... Additional parameters to be passed to the \code{\link{wd}} function of the \code{\link{wavethresh}} package for the wavelet decomposition of the otolith outlines
+#' @param object \code{\linkS4class{shapeR}}  
+#' @param ... Additional parameters to be passed to the [wavethresh::wd()] function package for the wavelet decomposition of the otolith outlines
 #' @return A \code{\linkS4class{shapeR}} object with values in slots:
 #' \itemize{
 #'   \item wavelet.coef.raw
@@ -219,8 +223,8 @@ setValidity("shapeR",
 #' @rdname generateShapeCoefficients
 #' @export generateShapeCoefficients
 #' @author Lisa Anne Libungan & Snaebjorn Palsson
-#' @seealso \code{\link[wavethresh]{wavethresh}}
-#' @references Nason, G. (2012). \code{\link{wavethresh}}: Wavelets statistics and transforms. R package, version 4.5.
+#' @seealso [wavethresh::wd()]
+#' @references Nason, G. (2012). [wavethresh::wd()]: Wavelets statistics and transforms. R package, version 4.5.
 #' @references Claude, J. (2008). Morphometrics with R. Springer. 316 p.
 generateShapeCoefficients <- function(object,...) {
   f.coef = matrix(NA,nrow=0,ncol= 32*4) # Maximum number of harmonics
@@ -367,7 +371,7 @@ generateShapeCoefficients <- function(object,...) {
 #' @author Lisa Anne Libungan & Snaebjorn Palsson
 #' @references Claude, J. (2008). Morphometrics with R. Springer. 316 p.
 #' @references Urbanek, S. (2014). \code{\link{jpeg}}: Read and write JPEG images. R package  version 0.1-8.
-#' @references Bivand, R., Leisch, F. & Maechler, M. (2011) \code{\link{pixmap}}: Bitmap Images (''Pixel Maps''). R package version 0.4-11.
+#' @references Bivand, R., Leisch, F. & Maechler, M. (2011) {pixmap}: Bitmap Images (''Pixel Maps''). R package version 0.4-11.
 #' @references Libungan LA and Palsson S (2015) ShapeR: An R Package to Study Otolith Shape Variation among Fish Populations. PLoS ONE 10(3): e0121102. \url{https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0121102}
 detect.outline <-
   function(object,threshold=0.2,mouse.click=FALSE,display.images=FALSE,write.outline.w.org = FALSE)
@@ -742,7 +746,7 @@ enrich.master.list <-
 #' @rdname plotWaveletShape
 #' @export plotWaveletShape
 #' @author Lisa Anne Libungan
-#' @references Nason, G. (2012) \code{\link{wavethresh}}: Wavelets statistics and transforms, version 4.5. R package.
+#' @references Nason, G. (2012) [wavethresh::wd()]: Wavelets statistics and transforms, version 4.5. R package.
 plotWaveletShape <-
   function(object,class.name,show.angle=FALSE,lty=1:5,col=1:6,...)
   {
@@ -1394,7 +1398,7 @@ outline.reconstruction.plot <- function(outline.rec.list,ref.w.level=5, ref.f.ha
 #' @rdname cluster.plot
 #' @export cluster.plot
 #' @author Lisa Anne Libungan
-#' @references Oksanen, J., Blanchet, F.G., Kindt, R., Legendre, P., Minchin, P.R., O'Hara, R.B., Simpson, G.L., Solymos, P., Stevens, M.H.H. and Wagner, H. (2013). \code{\link{vegan}}: Community Ecology Package. R package version 2.0-10.
+#' @references Oksanen, J., Blanchet, F.G., Kindt, R., Legendre, P., Minchin, P.R., O'Hara, R.B., Simpson, G.L., Solymos, P., Stevens, M.H.H. and Wagner, H. (2013). \code{\link[vegan:vegan-package]{vegan}}: Community Ecology Package. R package version 2.0-10.
 cluster.plot <- function( ddata,classes,main="",col.stock = NULL,plotCI=FALSE,conf.level=0.68,...)
 {
   dim.dd = dim(ddata)
